!****
!
! NAME
!  init_block.F90
!
! DESCRIPTION
!  Initializes values in the simulation box for the solar wind interaction. 
!  Initial values are set to represent a steady solar wind.  
!  Parameters for this steady solar wind are at runtime read from flash.par
!
! ARGUMENTS
!  blockID         The number of the block to intialize  
!
!****

subroutine Simulation_initBlock(blockID)

  !  Get Necessary Variables and Routines from Modules
  use Simulation_data, ONLY: sim_SWvelx, sim_SWvely, sim_SWvelz, & 
      		       	     		      sim_SWbx , sim_SWby, sim_SWbz, sim_divb, &
                                              sim_SWdens, sim_SWtemp, &
                                              sim_gamma

  use Grid_interface, ONLY: Grid_getBlkPtr, Grid_releaseBlkPtr

  use Eos_interface, ONLY: Eos

  implicit none

#include "constants.h"
#include "Flash.h"
#include "Eos.h"

  integer, intent(in) :: blockID

  real, pointer, dimension(:,:,:,:) :: inputData

  real, dimension(EOS_NUM) :: eosData

  real  ::  mu0
  real  ::  internalEnergy, kineticEnergy, totalEnergy, magPressure, pressure

  !  Set constants (permeability of free space)
  mu0 = 1.25663706e-6  

  !  Use Equation of State Module to get the internal energy and pressure
  eosData(EOS_TEMP) = sim_SWtemp
  eosData(EOS_DENS) = sim_SWdens
  
  call Eos(MODE_DENS_TEMP, 1, eosData)

  pressure = eosDATA(EOS_PRES)
  internalEnergy = eosDATA(EOS_EINT)


  !  Find the magnetic pressure
  magPressure = 0.5/mu0 * (sim_SWbx**2 + sim_SWby**2 + sim_SWbz**2)

  !  Find the kinetic energy and total energy
  kineticEnergy = 0.5 * sim_SWdens * (sim_SWvelx**2 + sim_SWvely**2 + sim_SWvelz**2)
  totalEnergy = internalEnergy + kineticEnergy

  
  !  Get input data pointer, initialize data, and release pointer
  call Grid_getBlkPtr(blockID, inputData, CENTER)

  inputData(VELX_VAR, :, :, :) = sim_SWvelx
  inputData(VELY_VAR, :, :, :) = sim_SWvely
  inputData(VELZ_VAR, :, :, :) = sim_SWvelz

  inputData(MAGX_VAR, :, :, :) = sim_SWbx  
  inputData(MAGY_VAR, :, :, :) = sim_SWby 
  inputData(MAGZ_VAR, :, :, :) = sim_SWbz
  inputData(DIVB_VAR, :, :, :)   = sim_divb
  inputData(MAGP_VAR, :, :, :) = magPressure

  inputData(DENS_VAR, :, :, :) = sim_SWdens
  inputData(TEMP_VAR, :, :, :) = sim_SWtemp 
  inputData(PRES_VAR, :, :, :)  = pressure 
  inputData(EINT_VAR, :, :, :)  = internalEnergy
  inputData(ENER_VAR, :, :, :) = totalEnergy

  inputData(GAMC_VAR, :, :, :) = sim_gamma
  inputData(GAME_VAR, :, :, :) = sim_gamma

  call Grid_releaseBlkPtr(blockID, inputData, CENTER)


end subroutine Simulation_initBlock

